/* autoupdate.js
======================================================================
==   Sage++ (Higmmer's Edition)                                     ==
==     Copyright (C) Higmmer.NEeT / Higmmer All Rights Reserved.    ==
==     The original Sage is the work of The Sage Project.           ==
======================================================================
*/


var auto_update_limit = 16;
var auto_update_mode = false;
var updated_feeds = null;
var exceeded_feed_num = 0;
var checking_folder_id = null;
var enable_unified_feed = false;
var unified_feed = null;
var render_feeds = true;


function autoUpdateInit(enableFlag) {
	var enabled = (enableFlag != null) ? enableFlag : CommonFunc.getPrefValue(CommonFunc.AUTO_UPDATE_ENABLE, "bool", false);

	try {
		auto_update_limit = CommonFunc.getPrefValue(CommonFunc.AUTO_UPDATE_LIMIT, "int", 16);
		enable_unified_feed = CommonFunc.getPrefValue(CommonFunc.AUTO_UPDATE_UNIFY_FEED, "bool", false);
		render_feeds = CommonFunc.getPrefValue(CommonFunc.RENDER_FEEDS, "bool", true);
	} catch(e) {
	}

	if(enabled && auto_update_limit > 0) {
		logMessage("auto updating is started with limit: " + auto_update_limit);
		UpdateChecker.onUpdated = autoUpdateProc;
		auto_update_mode = true;
		clearRssTitle();
		putMessageToRssTitle(strRes.getString("AUTOUPDATE_CHECKING"), null, null);
	} else {
		UpdateChecker.onUpdated = function(aFeed, aRes, aName, aURL) {}
		auto_update_mode = false;
	}
}

function autoUpdateProc(aFeed, aRes, aName, aURL) {
	if(!auto_update_mode) return;
	if(!updated_feeds) updated_feeds = new Array();

	if(updated_feeds.length < auto_update_limit) {
		var item = { feed:null, res:null };
		item.feed = aFeed;
		item.res = aRes;
		updated_feeds.push(item);
		putMessageToRssTitle(strRes.getString("AUTOUPDATE_FOUND"), updated_feeds.length,
		                     strRes.getString("AUTOUPDATE_FEEDS"));
		logMessage("auto updating is scheduled for feed: " + aName);
	} else {
		if(exceeded_feed_num == 0) {
			logMessage("auto updating exceeded limit: " + auto_update_limit);
			putMessageToRssTitle(strRes.getString("AUTOUPDATE_OVERLIMIT"),
			                     auto_update_limit + exceeded_feed_num);
		}
		exceeded_feed_num++;
	}
}

function doneUpdateCheck(folderId, foundFeeds) {
	UpdateChecker.onUpdated = function(aFeed, aRes, aName, aURL) {}
	checking_folder_id = folderId;
	clearRssTitle();
	if(auto_update_mode) {
		var scheduledFeeds = updated_feeds ? updated_feeds.length : 0;
		logMessage("auto updating is scheduled for " + scheduledFeeds + "/" + (scheduledFeeds + exceeded_feed_num) + " feed(s)");
	} else {
		showAlertOnUpdated(foundFeeds);
	}
	autoUpdateProgressNext(CommonFunc.getPrefValue(CommonFunc.OPEN_NEW_TAB_FOREGROUND, "bool", false));
}

function autoUpdateRenderProc(aFeed) {
	if(aFeed) {
		createUnifiedFeed(aFeed);
		if(render_feeds && !enable_unified_feed) CreateHTML.openHTML(aFeed);
	}

	clearRssTitle();
	rssStatusImage.setAttribute("loading", "false");
	rssStatusLabel.value = "";

	autoUpdateProgressNext(false);
}

function autoUpdateProgressNext(focusNewTab) {
	if(auto_update_mode && updated_feeds && updated_feeds.length > 0) {
		putMessageToRssTitle(strRes.getString("AUTOUPDATE_CREATING"), updated_feeds.length,
		                     strRes.getString("AUTOUPDATE_FEEDS"));
		CreateHTML.tabbed = true;
		CreateHTML.focusNewTab = focusNewTab;

		var item = updated_feeds.shift();
		if(item.feed != null) {
			updateFeedProperty(item.feed, item.res);
			window.setTimeout(autoUpdateRenderProc, 100, item.feed);
		} else {
			var url = _impl.getUrl(item.res);
			if(url) {
				lastResource = item.res;
				setStatusLoading();
				httpGet(url, true);
			}
		}
	} else {
		autoUpdateDone();
		autoUpdateCleanUp();
	}
}

function autoUpdateDone() {
	if(unified_feed) {
		if(enable_unified_feed) {
			removeVisitedItems(unified_feed);
			if(render_feeds) {
				CreateHTML.tabbed = true;
				CreateHTML.focusNewTab = CommonFunc.getPrefValue(CommonFunc.OPEN_NEW_TAB_FOREGROUND, "bool", false);
				CreateHTML.openHTML(unified_feed);
			}
		}
		if(CommonFunc.getPrefValue(CommonFunc.MARK_AS_READ_ON_CLOSING, "bool", false)) markAllAsReadForFeed(currentFeed);
		currentFeed = unified_feed;
	}

	setStatusDone();
	setRssItemListBox();

	if(auto_update_mode) {
		if(exceeded_feed_num > 0) {
			rssStatusLabel.value = exceeded_feed_num + " " + strRes.getString("AUTOUPDATE_REMAIN_FEEDS");
		}
		if(checking_folder_id) UpdateCounter.update(PlacesUtils.getFolderContents(checking_folder_id).root, false);
		logMessage("auto updating is done");
	}
	auto_update_mode = false;
}

function autoUpdateCleanUp() {
	if(updated_feeds) updated_feeds.splice(0);
	updated_feeds = null;
	exceeded_feed_num = 0;
	checking_folder_id = null;
	unified_feed = null;
}

function putMessageToRssTitle(aMsg1, count, aMsg2) {
	if(document.getElementById("rssItemListBoxBox").hidden) return;

	var msg = aMsg1;
	if(count != null) msg += " " + count;
	if(aMsg2 != null) msg += " " + aMsg2;
	rssTitleLabel.value = msg;
}

function clearRssTitle() {
	if(document.getElementById("rssItemListBoxBox").hidden) return;

	if(rssTitleLabel.value) {
		rssTitleLabel.value = "";
		rssTitleLabel.removeAttribute("href");
		rssTitleLabel.tooltipText = "";
	}
}

function createUnifiedFeed(aFeed) {
	if(enable_unified_feed) for each(var item in aFeed.items) {
		item.author = (item.author ? item.author + " - " : "") + aFeed.title;
	}
	if(!unified_feed) {
		var folder = PlacesUtils.getFolderContents(checking_folder_id, true).root;
		unified_feed = aFeed.clone();
		unified_feed.title = UpdateCounter._getRealTitle(folder);
		unified_feed.link = "about:blank";
		unified_feed.description = strRes.getString("AUTOUPDATE_UNIFIED_FEED");
		unified_feed.lastPubDate = new Date();
		unified_feed.path = ""; //"http://localhost/sagepp/unified_feed/folder?id=" + encodeURIComponent(_impl.getItemId(folder));
	} else {
		unified_feed.items = unified_feed.items.concat(aFeed.items);
	}
}

function removeVisitedItems(aFeed) {
	var items = aFeed.items;
	for(var i = items.length - 1; i >= 0; i--) {
		if(linkVisitor.getVisited(items[i].getLink())) items.splice(i, 1);
	}
}


/* End Of File */
